Bags of Binary Words
===================================

PyDBoW is a Python implementation of Bags of Binary Words algorithm.

## Requirements

- OpenCV
- numpy

## Installation

``` bash
pip install pydbow
```

## Usage

Refer to [demo.ipynb](https://github.com/goktug97/PyDBoW/tree/master/demo.ipynb) and
[demo.py](https://github.com/goktug97/PyDBoW/tree/master/demo.py) for example usage.

## Running tests

``` bash
python -m pytest
```

## License
PyDBoW is licensed under the MIT License.

Images are taken from https://github.com/commaai/comma10k 
